pub struct TmuxRetentionPolicy {
pub persistent: bool,
pub completed_window_ttl_secs: u64,
pub completed_window_max: u32,
}Expand description
Opt-in policy recorded on a run placed in a persistent tmux session.
Fields
persistent: boolKeep the selected session after the last worker completes.
completed_window_ttl_secs: u64Maximum age of a completed inert display.
completed_window_max: u32Maximum completed inert displays retained in this session.