pub struct TelemetryView {
pub sample: TelemetrySampleStatus,
pub state: Option<TelemetryState>,
pub age_ms: Option<i64>,
pub state_elapsed_ms: Option<i64>,
pub attempt: Option<u32>,
pub active_tool_count: Option<u8>,
pub tool_name: Option<String>,
}Expand description
Read view of one node’s advisory telemetry.
Fields
sample: TelemetrySampleStatusFreshness/corruption classification.
state: Option<TelemetryState>Last-told state when a valid current-attempt sample exists.
age_ms: Option<i64>Age in milliseconds, unavailable when the clock is unreliable.
state_elapsed_ms: Option<i64>Time since this state was first received, unavailable with a bad clock.
attempt: Option<u32>Sample attempt.
active_tool_count: Option<u8>Bounded active-tool count.
tool_name: Option<String>Sanitized single-tool name.